@@ -8,7 +8,7 @@ import koji
 import yaml
 import json
 
-from doozerlib import brew, state, exectools, embargo_detector
+from doozerlib import brew, state, exectools, embargo_detector, rhcos
 from doozerlib.cli import cli, pass_runtime
 from doozerlib.exceptions import DoozerFatalError
 from doozerlib.image import ImageMetadata
@@ -16,10 +16,10 @@ from doozerlib.util import red_print, yellow_print
 
 
 @cli.command("release:gen-payload", short_help="Generate input files for release mirroring")
-@click.option("--is-name", metavar='NAME', required=True,
-              help="ImageStream .metadata.name value. Something like '4.2-art-latest'")
-@click.option("--is-namespace", metavar='NAMESPACE', required=False, default='ocp',
-              help="ImageStream .metadata.namespace value.\ndefault=ocp")
+@click.option("--is-name", metavar='NAME', required=False,
+              help="ImageStream .metadata.name value. For example '4.2-art-latest'")
+@click.option("--is-namespace", metavar='NAMESPACE', required=False,
+              help="ImageStream .metadata.namespace value. For example 'ocp'")
 @click.option("--organization", metavar='ORGANIZATION', required=False, default='openshift-release-dev',
               help="Quay ORGANIZATION to mirror into.\ndefault=openshift-release-dev")
 @click.option("--repository", metavar='REPO', required=False, default='ocp-v4.0-art-dev',
@@ -47,8 +47,9 @@ For automation purposes this command generates a mirroring yaml files
 after the arch-specific files have been generated. The yaml files
 include names of generated content.
 
-YOU MUST PROVIDE the base name for the image streams. The generated
-files will append the -arch suffix to the given name.
+You may provide the namespace and base name for the image streams, or defaults
+will be used. The generated files will append the -arch and -priv suffixes to
+the given name and namespace as needed.
 
 The ORGANIZATION and REPOSITORY options are combined into
 ORGANIZATION/REPOSITORY when preparing for mirroring.
@@ -71,26 +72,33 @@ that particular tag.
     runtime.state[cmd] = dict(state.TEMPLATE_IMAGE)
     lstate = runtime.state[cmd]  # get local convenience copy
 
+    if not is_name:
+        is_name = default_is_base_name(runtime.get_minor_version())
+    if not is_namespace:
+        is_namespace = default_is_base_namespace()
+
     images = [i for i in runtime.image_metas()]
     lstate['total'] = len(images)
 
     no_build_items = []
     invalid_name_items = []
 
-    ose_prefixed_images = []
+    payload_images = []
     for image in images:
         # Per clayton:
         """Tim Bielawa: note to self: is only for `ose-` prefixed images
         Clayton Coleman: Yes, Get with the naming system or get out of town
         """
-        if not image.image_name_short.startswith("ose-"):
-            invalid_name_items.append(image.image_name_short)
-            red_print("NOT adding to IS (does not meet name/version conventions): {}".format(image.image_name_short))
-            continue
-        ose_prefixed_images.append(image)
+        if image.is_payload:
+            if not image.image_name_short.startswith("ose-"):
+                invalid_name_items.append(image.image_name_short)
+                red_print("NOT adding to IS (does not meet name/version conventions): {}".format(image.image_name_short))
+                continue
+            else:
+                payload_images.append(image)
 
     runtime.logger.info("Fetching latest image builds from Brew...")
-    tag_component_tuples = [(image.candidate_brew_tag(), image.get_component_name()) for image in ose_prefixed_images]
+    tag_component_tuples = [(image.candidate_brew_tag(), image.get_component_name()) for image in payload_images]
     brew_session = runtime.build_retrying_koji_client()
     latest_builds = brew.get_latest_builds(tag_component_tuples, "image", event_id, brew_session)
     latest_builds = [builds[0] if builds else None for builds in latest_builds]  # flatten the data structure
@@ -99,7 +107,7 @@ that particular tag.
     build_ids = [b["id"] if b else 0 for b in latest_builds]
     archives_list = brew.list_archives_by_builds(build_ids, "image", brew_session)
 
-    mismatched_siblings = find_mismatched_siblings(ose_prefixed_images, latest_builds, archives_list, runtime.logger, lstate)
+    mismatched_siblings = find_mismatched_siblings(payload_images, latest_builds, archives_list, runtime.logger, lstate)
 
     embargoed_build_ids = set()  # a set of private image build ids
     if runtime.group_config.public_upstreams:
@@ -115,7 +123,7 @@ that particular tag.
 
     # These will map[arch] -> map[image_name] -> { version: version, release: release, image_src: image_src }
     mirroring = {}
-    for i, image in enumerate(ose_prefixed_images):
+    for i, image in enumerate(payload_images):
         latest_build = latest_builds[i]
         archives = archives_list[i]
         error = None
@@ -162,14 +170,7 @@ that particular tag.
 
         mirror_filename = 'src_dest.{}'.format(key)
         imagestream_filename = 'image_stream.{}'.format(key)
-        target_is_name = is_name
-        target_is_namespace = is_namespace
-        if arch != 'x86_64':
-            target_is_name = '{}-{}'.format(target_is_name, arch)
-            target_is_namespace = '{}-{}'.format(target_is_namespace, arch)
-        if private:
-            target_is_name += "-priv"
-            target_is_namespace += "-priv"
+        target_is_name, target_is_namespace = is_name_and_space(is_name, is_namespace, arch, private)
 
         def build_dest_name(tag_name):
             entry = mirroring[key][tag_name]
@@ -211,21 +212,11 @@ that particular tag.
                     }
                 })
 
-            # TODO: @jupierce: Let's comment this out for now. I need to explore some options with the rhcos team.
-            # if private:
-            #     # mirroring rhcos
-            #     runtime.logger.info(f"Getting latest RHCOS pullspec for {arch}...")
-            #     source_is_namespace = target_is_namespace[:-5]  # strip `-priv`
-            #     rhcos_pullspec = get_latest_rhcos_pullspec(source_is_namespace, target_is_name)
-            #     if not rhcos_pullspec:
-            #         yellow_print(f"No RHCOS found from imagestream {target_is_name} in namespace {source_is_namespace}.")  # should we throw an error?
-            #     tag_list.append({
-            #         'name': "machine-os-content",
-            #         'from': {
-            #             'kind': 'DockerImage',
-            #             'name': rhcos_pullspec
-            #         }
-            #     })
+            # mirroring rhcos
+            runtime.logger.info(f"Getting latest RHCOS pullspec for {target_is_name}...")
+            mosc_istag = _latest_mosc_istag(runtime, arch, private)
+            if mosc_istag:
+                tag_list.append(mosc_istag)
 
             # Not all images are built for non-x86 arches (e.g. kuryr), but they
             # may be mentioned in image references. Thus, make sure there is a tag
@@ -264,18 +255,41 @@ that particular tag.
         for img in sorted(invalid_name_items):
             click.echo("   {}".format(img))
 
-# TODO: @jupierce: Let's comment this out for now. I need to explore some options with the rhcos team.
-# def get_latest_rhcos_pullspec(namespace, image_stream_name):
-#     rhcos_tag = "machine-os-content"
-#     out, _ = exectools.cmd_assert(["oc", "get", "imagestream", image_stream_name, "-n", namespace, "-o", "json"])
-#     imagestream = json.loads(out)
-#     for tag_entry in imagestream["status"]["tags"]:
-#         if tag_entry["tag"] != rhcos_tag:
-#             continue
-#         items = tag_entry.get("items")
-#         if items:
-#             return items[0]["dockerImageReference"]  # the first item should be latest
-#     return None  # rhcos image is not found
+
+def default_is_base_name(version):
+    return f"{version}-art-latest"
+
+
+def default_is_base_namespace():
+    return "ocp"
+
+
+def is_name_and_space(base_name, base_namespace, arch, private):
+    arch_suffix = "" if arch == 'x86_64' else f"-{arch}"
+    priv_suffix = "-priv" if private else ""
+    name = f"{base_name}{arch_suffix}{priv_suffix}"
+    namespace = f"{base_namespace}{arch_suffix}{priv_suffix}"
+    return name, namespace
+
+
+def _latest_mosc_istag(runtime, arch, private):
+    try:
+        version = runtime.get_minor_version()
+        _, pullspec = rhcos.latest_machine_os_content(version, arch, private)
+        if not pullspec:
+            yellow_print(f"No RHCOS found for {version} arch={arch} private={private}")
+            return None
+    except Exception as ex:
+        yellow_print(f"error finding RHCOS: {ex}")
+        return None
+
+    return {
+        'name': "machine-os-content",
+        'from': {
+            'kind': 'DockerImage',
+            'name': pullspec
+        }
+    }
 
 
 def find_mismatched_siblings(images, builds, archives_list, logger, lstate):
