@@ -15,7 +15,7 @@ import traceback
 import glob
 
 from .pushd import Dir
-from .distgit import ImageDistGitRepo, RPMDistGitRepo
+from .distgit import ImageDistGitRepo, RPMDistGitRepo, DistGitRepo
 from . import exectools
 from . import logutil
 
@@ -112,7 +112,7 @@ class Metadata(object):
             return f'ssh://{self.runtime.user}@{pkgs_host}/{self.qualified_name}'
         return f'ssh://{pkgs_host}/{self.qualified_name}'
 
-    def distgit_repo(self, autoclone=True):
+    def distgit_repo(self, autoclone=True) -> DistGitRepo:
         if self._distgit_repo is None:
             self._distgit_repo = DISTGIT_TYPES[self.meta_type](self, autoclone=autoclone)
         return self._distgit_repo
@@ -292,7 +292,12 @@ class Metadata(object):
         if source_dir:
             with Dir(source_dir):
                 # Not every repo has a master branch, they may have a different default; detect it.
-                remote_info, _ = exectools.cmd_assert('git remote show origin')
+                if self.public_upstream_url:
+                    # If there is a public upstream, query it for the default branch. The openshift-priv
+                    # clones seem to be non-deterministic on which branch is set as default.
+                    remote_info, _ = exectools.cmd_assert('git remote show public_upstream')
+                else:
+                    remote_info, _ = exectools.cmd_assert('git remote show origin')
                 head_branch_lines = [i for i in remote_info.splitlines() if i.strip().startswith('HEAD branch:')]  # e.g. [ "  HEAD branch: master" ]
                 if not head_branch_lines:
                     raise IOError('Error trying to detect remote default branch')
@@ -395,6 +400,7 @@ class Metadata(object):
                 godep_kube_minor = '0' if len(kube_version_fields) < 2 else kube_version_fields[1]
                 envs['KUBE_GIT_MINOR'] = f'{godep_kube_minor}+'  # For historical reasons, append a '+' since OCP patches its vendored kube.
                 envs['KUBE_GIT_COMMIT'] = kube_commit_hash
+                envs['KUBE_GIT_TREE_STATE'] = 'clean'
             elif self.name in ('openshift-enterprise-hyperkube', 'openshift', 'atomic-openshift'):
                 self.logger.critical(f'Unable to acquire KUBE vars for {self.name}. This must be fixed or platform addons can break: https://bugzilla.redhat.com/show_bug.cgi?id=1861097')
                 raise IOError(f'Unable to determine KUBE vars for {self.name}')
